@@ -6,7 +6,7 @@ Toadfarm - One Mojolicious app to rule them all
 
 =head1 VERSION
 
-0.40
+0.41
 
 =head1 SYNOPSIS
 
@@ -151,7 +151,9 @@ use Mojo::Base 'Mojolicious';
 use Mojo::Util 'class_to_path';
 use File::Which;
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
+
+$ENV{MOJO_CONFIG} = $ENV{TOADFARM_CONFIG} if $ENV{TOADFARM_CONFIG};
 
 =head1 METHODS
 
@@ -165,6 +167,9 @@ sub startup {
   my $self = shift;
   my $config = $ENV{MOJO_CONFIG} ? $self->plugin('Config') : {};
 
+  # remember the config when hot reloading the app
+  $ENV{TOADFARM_CONFIG} = delete $ENV{MOJO_CONFIG};
+
   if($config->{log}{file}) {
     my $log = Mojo::Log->new;
     $log->path($config->{log}{file});
@@ -205,8 +210,6 @@ sub _start_apps {
     my $path = $name;
     my($app, $request_base, @over, @error);
 
-    delete local $ENV{MOJO_CONFIG};
-
     $path = File::Which::which($path) || class_to_path($path) unless -r $path;
     $app ||= eval { $server->load_app($path) } or push @error, $@;
     $app ||= eval { $server->build_app($name) } or push @error, $@;
@@ -226,7 +229,9 @@ sub _start_apps {
 
     while(my($name, $value) = each %$rules) {
       $request_base = $value if $name eq 'X-Request-Base';
-      push @over, "return 0 unless +(\$h->header('$name') // '') eq '$value';\n";
+      push @over, ref $value
+        ? "return 0 unless +(\$h->header('$name') // '') =~ /$value/;\n"
+        : "return 0 unless +(\$h->header('$name') // '') eq '$value';\n";
     }
 
     if(@over) {
